<?php $TRANSLATIONS = array(
"Pictures" => "Immagini",
"Shared by" => "Condiviso da",
"Share" => "Condividi",
"The \"Image Viewer\" application also need to be enabled to use this application." => "Per utilizzare questa applicazione deve essere abilitato anche il \"Visualizzatore immagini\"."
);
